@@ -1,4 +1,4 @@
-available_rblood2plasma <- function(chem.cas=NULL,chem.name=NULL,species='Human',Funbound.plasma.pc.correction=T)
+available_rblood2plasma <- function(chem.cas=NULL,chem.name=NULL,species='Human',adjusted.Funbound.plasma=T)
 {
   chem.physical_and_invitro.data <- chem.physical_and_invitro.data
   Rblood2plasma <- get_rblood2plasma(chem.name=chem.name,chem.cas=chem.cas,species=species) 
@@ -12,10 +12,10 @@ available_rblood2plasma <- function(chem.cas=NULL,chem.name=NULL,species='Human'
       chem.cas <- out$chem.cas
     }
     if(chem.cas %in% get_cheminfo(species=species,model='schmitt')){
-      Rblood2plasma <- calc_rblood2plasma(chem.cas=chem.cas,species=species,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction)
+      Rblood2plasma <- calc_rblood2plasma(chem.cas=chem.cas,species=species,adjusted.Funbound.plasma=adjusted.Funbound.plasma)
       warning(paste(species,'Rblood2plasma calculated with calc_rblood2plasma.')) 
     }else if(chem.cas %in% get_cheminfo(species='Human',model='schmitt')){
-      Rblood2plasma <- calc_rblood2plasma(chem.cas=chem.cas,species=species,default.to.human=T,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction)
+      Rblood2plasma <- calc_rblood2plasma(chem.cas=chem.cas,species=species,default.to.human=T,adjusted.Funbound.plasma=adjusted.Funbound.plasma)
       warning(paste(species,'Rblood2plasma calculated with Human Funbound.plasma.'))
     }else{
       Rblood2plasma.data <- chem.physical_and_invitro.data[,'Human.Rblood2plasma']
