@@ -17,21 +17,22 @@ solve_1comp <- function(chem.cas=NULL,
                         default.to.human=F,
                         dosing.matrix = NULL,
                         recalc.elimination=F,
-                        Funbound.plasma.pc.correction=T,
+                        adjusted.Funbound.plasma=T,
+                        regression=T,
                         restrictive.clearance=T,
                         well.stirred.correction=T,                        
                         ...)
 {     
    Agutlumen <- Acompartment <- Ccompartment <- NULL 
   if(is.null(chem.cas) & is.null(chem.name) & is.null(parameters)) stop('Parameters, chem.name, or chem.cas must be specified.')
-  if(is.null(parameters)){  parameters <- parameterize_1comp(chem.name=chem.name,chem.cas=chem.cas,species=species,default.to.human=default.to.human,Funbound.plasma.pc.correction=Funbound.plasma.pc.correction,restrictive.clearance=restrictive.clearance,well.stirred.correction=well.stirred.correction,suppress.messages=suppress.messages) 
+  if(is.null(parameters)){  parameters <- parameterize_1comp(chem.name=chem.name,chem.cas=chem.cas,species=species,default.to.human=default.to.human,adjusted.Funbound.plasma=adjusted.Funbound.plasma,regression=regression,restrictive.clearance=restrictive.clearance,well.stirred.correction=well.stirred.correction,suppress.messages=suppress.messages) 
   }else{
     name.list <- c("Vdist","kelim","kgutabs","Rblood2plasma","MW","million.cells.per.gliver","hematocrit","Fgutabs")
     if(!all(name.list %in% names(parameters)))stop(paste("Missing parameters:",paste(name.list[which(!name.list %in% names(parameters))],collapse=', '),".  Use parameters from parameterize_1comp."))
   }
   Rb2p <- parameters[['Rblood2plasma']]
-    
-
+  
+  parameters$Fgutabs <- parameters$Fgutabs * parameters$hepatic.bioavailability
 
   if(is.null(times)) times <- round(seq(0, days, 1/(24*tsteps)),8)
   start <- times[1]
@@ -122,7 +123,7 @@ solve_1comp <- function(chem.cas=NULL,
   }
   parameters[['ke']] <- parameters[['kelim']]   
   parameters[['vdist']] <- parameters[['Vdist']]
-  parameters <- initparms1comp(parameters[!(names(parameters) %in% c("kelim","Rblood2plasma","MW",'Vdist','million.cells.per.gliver','hematocrit','Fgutabs'))])
+  parameters <- initparms1comp(parameters[!(names(parameters) %in% c("kelim","Rblood2plasma","MW",'Vdist','million.cells.per.gliver','hematocrit','Fgutabs','hepatic.bioavailability'))])
   
   state <-initState1comp(parameters,state)
   
@@ -131,26 +132,18 @@ solve_1comp <- function(chem.cas=NULL,
     if(is.null(doses.per.day)){
       out <- ode(y = state, times = times,func="derivs1comp", parms=parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,...)
     }else{
-      if(iv.dose){
-        dosing <- seq(start + 1/doses.per.day,end-1/doses.per.day,1/doses.per.day)
-        length <- length(dosing)
-        eventdata <- data.frame(var=rep('Acompartment',length),time = round(dosing,8),value = rep(dose,length), method = rep("add",length))                          
-        out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
-      }else{
-        dosing <- seq(start + 1/doses.per.day,end-1/doses.per.day,1/doses.per.day)
-        length <- length(dosing)
-        eventdata <- data.frame(var=rep('Agutlumen',length),time = round(dosing,8),value = rep(dose,length), method = rep("add",length))                          
-        out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
-      }
+      dosing <- seq(start + 1/doses.per.day,end-1/doses.per.day,1/doses.per.day)
+      length <- length(dosing)
+      if(iv.dose) eventdata <- data.frame(var=rep('Acompartment',length),time = round(dosing,8),value = rep(dose,length), method = rep("add",length))           
+      else eventdata <- data.frame(var=rep('Agutlumen',length),time = round(dosing,8),value = rep(dose,length), method = rep("add",length)) 
+      times <- sort(c(times,dosing + 1e-8,1e-8))               
+      out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
     }
   }else{
-    if(iv.dose){
-      eventdata <- data.frame(var=rep('Acompartment',length(dosing.times)),time = dosing.times,value = dose.vector, method = rep("add",length(dosing.times)))                          
-      out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
-    }else{
-      eventdata <- data.frame(var=rep('Agutlumen',length(dosing.times)),time = dosing.times,value = dose.vector, method = rep("add",length(dosing.times)))                          
-      out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
-    }
+    if(iv.dose) eventdata <- data.frame(var=rep('Acompartment',length(dosing.times)),time = dosing.times,value = dose.vector, method = rep("add",length(dosing.times)))
+    else eventdata <- data.frame(var=rep('Agutlumen',length(dosing.times)),time = dosing.times,value = dose.vector, method = rep("add",length(dosing.times)))                          
+    times <- sort(c(times,dosing.times + 1e-8,1e-8))
+    out <- ode(y = state, times = times, func="derivs1comp", parms = parameters, method=method,rtol=rtol,atol=atol, dllname="httk",initfunc="initmod1comp", nout=length(Outputs1comp),outnames=Outputs1comp,events=list(data=eventdata),...)
   }
    
 
